# mypy-boto3-securityhub

Mypy-friendly auto-generated type annotations for `boto3 securityhub 1.10.39` service.
More information can be found [here](https://github.com/vemel/mypy_boto3).

- [mypy-boto3-securityhub](#mypy-boto3-securityhub)
  - [How to use](#how-to-use)
    - [Type checking](#type-checking)
    - [Code auto-complete](#code-auto-complete)
  - [How it works](#how-it-works)

## How to use

### Type checking

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `securityhub` service.

```bash
python -m pip install boto3-stubs[mypy-boto3-securityhub]
```

Use `boto3` with `mypy_boto3` in your project and enjoy type checking.

```python
import boto3

from mypy_boto3 import securityhub
# alternative import if you do not want to install mypy_boto3 package
# import mypy_boto3_securityhub as securityhub

# Use this client as usual, now mypy can check if your code is valid.
# Check if your IDE supports function overloads,
# you probably do not need explicit type annotations
# client = boto3.client("securityhub")
client: securityhub.SecurityHubClient = boto3.client("securityhub")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: securityhub.SecurityHubClient = session.client("securityhub")


# Paginators need type annotation on creation
get_enabled_standards_paginator: securityhub.GetEnabledStandardsPaginator = client.get_paginator("get_enabled_standards")
get_findings_paginator: securityhub.GetFindingsPaginator = client.get_paginator("get_findings")
get_insights_paginator: securityhub.GetInsightsPaginator = client.get_paginator("get_insights")
list_enabled_products_for_import_paginator: securityhub.ListEnabledProductsForImportPaginator = client.get_paginator("list_enabled_products_for_import")
list_invitations_paginator: securityhub.ListInvitationsPaginator = client.get_paginator("list_invitations")
list_members_paginator: securityhub.ListMembersPaginator = client.get_paginator("list_members")
```

## How it works

Fully automated [builder](https://github.com/vemel/mypy_boto3) carefully generates
type annotations for each service, patiently waiting for `boto3` updates. It delivers
a drop-in type annotations for you and makes sure that:

- Latest version of `boto3` is used.
- Each public class and method of every `boto3` service gets valid type annotations
  extracted from latest documentation (blame `botocore` docs if types are incorrect).
- Type annotations include up-to-date documentation.
- Code is processed by [black](https://github.com/psf/black) for readability.